==> zio-aws-acmpca_2.13-5.17.104.8-sources.jar: zio/aws/acmpca/model/ListTagsResponse.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.acmpca.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListTagsResponse(
    tags: Option[Iterable[zio.aws.acmpca.model.Tag]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.ListTagsResponse = {
    import ListTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.ListTagsResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.ListTagsResponse.ReadOnly =
    zio.aws.acmpca.model.ListTagsResponse.wrap(buildAwsValue())
}
object ListTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.ListTagsResponse =
      zio.aws.acmpca.model.ListTagsResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tags: Option[List[zio.aws.acmpca.model.Tag.ReadOnly]]
    def nextToken: Option[NextToken]
    def getTags: ZIO[Any, AwsError, List[zio.aws.acmpca.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ) extends zio.aws.acmpca.model.ListTagsResponse.ReadOnly {
    override val tags: Option[List[zio.aws.acmpca.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.acmpca.model.Tag.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.acmpca.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ): zio.aws.acmpca.model.ListTagsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-acmpca_2.13-5.17.265.1-sources.jar: zio/aws/acmpca/model/ListTagsResponse.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.acmpca.model.primitives.NextToken
import scala.jdk.CollectionConverters._
final case class ListTagsResponse(
    tags: Optional[Iterable[zio.aws.acmpca.model.Tag]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.ListTagsResponse = {
    import ListTagsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.ListTagsResponse
      .builder()
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.ListTagsResponse.ReadOnly =
    zio.aws.acmpca.model.ListTagsResponse.wrap(buildAwsValue())
}
object ListTagsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.ListTagsResponse =
      zio.aws.acmpca.model.ListTagsResponse(
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tags: Optional[List[zio.aws.acmpca.model.Tag.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getTags: ZIO[Any, AwsError, List[zio.aws.acmpca.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ) extends zio.aws.acmpca.model.ListTagsResponse.ReadOnly {
    override val tags: Optional[List[zio.aws.acmpca.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.acmpca.model.Tag.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.acmpca.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.ListTagsResponse
  ): zio.aws.acmpca.model.ListTagsResponse.ReadOnly = new Wrapper(impl)
}
